summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/groupwise/libgroupwise/tasks/updatefoldertask.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/groupwise/libgroupwise/tasks/updatefoldertask.cpp')
-rw-r--r--kopete/protocols/groupwise/libgroupwise/tasks/updatefoldertask.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kopete/protocols/groupwise/libgroupwise/tasks/updatefoldertask.cpp b/kopete/protocols/groupwise/libgroupwise/tasks/updatefoldertask.cpp
index af0785de..3f8ff7bf 100644
--- a/kopete/protocols/groupwise/libgroupwise/tasks/updatefoldertask.cpp
+++ b/kopete/protocols/groupwise/libgroupwise/tasks/updatefoldertask.cpp
@@ -21,7 +21,7 @@
#include "updatefoldertask.h"
-UpdateFolderTask::UpdateFolderTask(Task* tqparent): UpdateItemTask(tqparent)
+UpdateFolderTask::UpdateFolderTask(Task* parent): UpdateItemTask(parent)
{
}
@@ -39,7 +39,7 @@ void UpdateFolderTask::renameFolder( const TQString & newName, const GroupWise::
renamed.name = newName;
// add the new version of the folder, marked add
lst.append( new Field::MultiField( NM_A_FA_FOLDER, NMFIELD_METHOD_ADD, 0, NMFIELD_TYPE_ARRAY, folderToFields( renamed ) ) );
// let our tqparent class package it up as a contactlist in a transfer
UpdateItemTask::item( lst );
}
@@ -39,7 +39,7 @@ void UpdateFolderTask::renameFolder( const TQString & newName, const GroupWise::
// add the new version of the folder, marked add
lst.append( new Field::MultiField( NM_A_FA_FOLDER, NMFIELD_METHOD_ADD, 0, NMFIELD_TYPE_ARRAY, folderToFields( renamed ) ) );
- // let our tqparent class package it up as a contactlist in a transfer
+ // let our parent class package it up as a contactlist in a transfer
UpdateItemTask::item( lst );
}